@@ -8,13 +8,13 @@
 ## usethis namespace: end
 NULL
 
-#' @noRd
-#' @importFrom libproj libproj_version
-.libproj_version <- function() {
-  ## purely to pass check
-  libproj::libproj_version()
-}
-NULL
+# @noRd
+# @importFrom libproj libproj_version
+# .libproj_version <- function() {
+#   ## purely to pass check
+#   libproj::libproj_version()
+# }
+#NULL
 
 
 #' Generic Coordinate System Transformations Using 'PROJ'
